@@ -10,8 +10,8 @@ int main(int argc, char *argv[])
 
 	Utilities utils;
     QmlApplicationViewer viewer;
-//	viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
-	viewer.setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
+	viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
+//	viewer.setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
 	viewer.setWindowTitle("QtWeather");
 	viewer.rootContext()->setContextProperty("Utilities", &utils);
 	viewer.setMainQmlFile(QLatin1String("qml/qtweather-qml/main.qml"));
@@ -26,13 +26,3 @@ int main(int argc, char *argv[])
 
 	return app.exec();
 }
-
-
-//void toggleFullScreen()
-//	 {
-//		 bool isFullScreen = windowState() & Qt::WindowFullScreen;
-//		 if (isFullScreen)
-//			 showNormal();
-//		 else
-//			 showFullScreen();
-//	 }
