@@ -7,6 +7,24 @@ Utilities::Utilities(QObject *parent) :
 
 }
 
+/**
+Get the zipcode of a corresponding home
+@param homeNum home identifier (ie "home1")
+@return The zipcode of homeNum, else "" if none exists
+*/
+QString Utilities::home(QString homeNum){
+	return settings->value(homeNum, "").toString();
+}
+
+/**
+  Set the zipcode of a home
+  @param homeNum home identifier (ie "home1")
+  @param zipcode The zipcode to be set
+  */
+void Utilities::setHome(QString homeNum, QString zipcode){
+	settings->setValue(homeNum, zipcode);
+}
+
 QString Utilities::home1(){
 	return settings->value("home1", "").toString();
 }
@@ -44,7 +62,9 @@ int Utilities::strSize(QString string){
 }
 
 void Utilities::minimize(){
+#ifdef Q_WS_MAEMO_5
 	system("dbus-send --type=signal --session /com/nokia/hildon_desktop com.nokia.hildon_desktop.exit_app_view");
+#endif
 }
 
 bool Utilities::substr(QString basestr, QString search){
