@@ -15,6 +15,9 @@ public:
 		return QUrl::fromPercentEncoding(string.toStdString().c_str());
 	}
 
+	Q_INVOKABLE QString home(QString homeNum);
+	Q_INVOKABLE void setHome(QString homeNum, QString zipcode);
+
 	Q_INVOKABLE QString home1();
 	Q_INVOKABLE QString home2();
 	Q_INVOKABLE int defaultHome();
